@@ -1,9 +1,9 @@
-/*!
+/*@preserve
 
 JSZipUtils - A collection of cross-browser utilities to go along with JSZip.
 <http://stuk.github.io/jszip-utils>
 
-(c) 2014 Stuart Knightley, David Duponchel
+(c) 2014-2019 Stuart Knightley, David Duponchel
 Dual licenced under the MIT license or GPLv3. See https://raw.github.com/Stuk/jszip-utils/master/LICENSE.markdown.
 
 */
